pub struct IbvBackend(pub ActorHandle<IbvManagerActor>);Expand description
Wrapper around ActorHandle<IbvManagerActor> that moves the RDMA
data-plane (post send/recv, poll CQ) off the actor loop while keeping
state-mutating operations (MR registration/deregistration, QP management)
serialized through actor messages.
Tuple Fields
0: ActorHandle<IbvManagerActor>Methods from Deref<Target = ActorHandle<IbvManagerActor>>
Sourcepub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
pub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to drain its current messages and then stop.
Sourcepub fn status(&self) -> Receiver<ActorStatus>
pub fn status(&self) -> Receiver<ActorStatus>
A watch that observes the lifecycle state of the actor.
Sourcepub fn send<M>(
&self,
cx: &impl Actor,
message: M,
) -> Result<(), MailboxSenderError>
pub fn send<M>( &self, cx: &impl Actor, message: M, ) -> Result<(), MailboxSenderError>
Send a message to the actor. Messages sent through the handle are always queued in process, and do not require serialization.
Sourcepub fn port<M>(&self) -> PortHandle<M>
pub fn port<M>(&self) -> PortHandle<M>
Return a port for the provided message type handled by the actor.